/*!
 * runedu-js-sdk.js v0.34.2
 */
/**
 * 创建script
 * @param  {string}     src 地址
 * @param  {function}   resolve 加载成功回调
 * @param  {function}   reject  加载失败回调
 * @return {object}     promise
 */

var createScript = src =>
    new Promise((resolve, reject) => {
        let el = document.createElement('script');
        el.src = src;
        el.onload = () => {
            resolve(el);
            el = null;
        };
        el.onerror = (err) => {
            reject(err);
            el.parentNode.removeChild(el);
            el = null;
        };
        document.getElementsByTagName('body')[0].appendChild(el);
    });

// 百度统计
var BDTJ = (APPID) => {
    createScript(`//hm.baidu.com/hm.js?${APPID}`);
};

let sdk;
let loading = false;
let callbackList = [];

const doCallbackList = (bl, res) => {
    if (bl) {
        callbackList.forEach(({ resolve }) => {
            resolve(sdk);
        });
    } else {
        callbackList.forEach(({ reject }) => {
            reject(res);
        });
    }
    loading = false;
    callbackList = [];
};

var init = APPID => () => {
    if (sdk) {
        return Promise.resolve(sdk)
    }

    if (!loading) {
        loading = true;
        createScript(`https://jic.talkingdata.com/app/h5/v1?appid=${APPID}&vn=v3`).then(
            () => {
                sdk = window.TDAPP;
                doCallbackList(true);
            },
            (res) => {
                doCallbackList(false, res);
            }
        );
    }

    return new Promise((resolve, reject) => {
        callbackList.push({
            resolve,
            reject
        });
    })
};

var TD = (APPID) => {
    const getSDK = init(APPID);
    return (...reset) => {
        getSDK().then((sdk) => {
            sdk.onEvent(...reset);
        });
    }
};

var getWechatCode = appid => (returnUrl, needInfo, state = '') => {
    const options = {
        appid,
        redirect_uri: window.encodeURIComponent(returnUrl),
        scope: needInfo ? 'snsapi_userinfo' : 'snsapi_base',
        response_type: 'code',
        state
    };

    const search = Object.keys(options)
        .map(item => `${item}=${options[item]}`)
        .join('&');

    window.location.href = `https://open.weixin.qq.com/connect/oauth2/authorize?${search}#wechat_redirect`;
};

/**
 * 获取微信jssdk引用
 * http://mp.weixin.qq.com/wiki/7/aaa137b55fb2e0456bf8dd9148dd613f.html
 */

let loading$1 = false;
let sdk$1 = window.wx; // 可能被全局引入了
let callbackList$1 = [];

const doCallbackList$1 = (bl, res) => {
    if (bl) {
        callbackList$1.forEach(({ success }) => {
            success(sdk$1);
        });
    } else {
        callbackList$1.forEach(({ error }) => {
            error(res);
        });
    }
    loading$1 = false;
    callbackList$1 = [];
};

const init$1 = (config) => {
    // 需要使用的JS接口列表
    const jsApiList = [
        'onMenuShareTimeline',
        'onMenuShareAppMessage',
        'onMenuShareQQ',
        'onMenuShareWeibo',
        'onMenuShareQZone',
        'startRecord',
        'stopRecord',
        'onVoiceRecordEnd',
        'playVoice',
        'pauseVoice',
        'stopVoice',
        'onVoicePlayEnd',
        'uploadVoice',
        'downloadVoice',
        'chooseImage',
        'previewImage',
        'uploadImage',
        'downloadImage',
        'translateVoice',
        'getNetworkType',
        'openLocation',
        'getLocation',
        'hideOptionMenu',
        'showOptionMenu',
        'hideMenuItems',
        'showMenuItems',
        'hideAllNonBaseMenuItem',
        'showAllNonBaseMenuItem',
        'closeWindow',
        'scanQRCode',
        'chooseWXPay',
        'openProductSpecificView',
        'addCard',
        'chooseCard',
        'openCard'
    ];

    sdk$1.config({
        debug: process.env.NODE_ENV === 'development', // 开启调试模式。
        appId: config.appid, // 必填，公众号的唯一标识
        timestamp: config.timestamp, // 必填，生成签名的时间戳
        nonceStr: config.noncestr, // 必填，生成签名的随机串
        signature: config.signature, // 必填，签名，见附录1
        jsApiList // 必填，需要使用的JS接口列表，所有JS接口列表见附录2
    });

    sdk$1.ready(() => {
        doCallbackList$1(true);
    });

    sdk$1.error((err) => {
        doCallbackList$1(false, err);
    });
};

var getWechatSDK = getConfig => () => {
    if (sdk$1) {
        return Promise.resolve(sdk$1)
    }

    if (!loading$1) {
        loading$1 = true;
        createScript('//res.wx.qq.com/open/js/jweixin-1.3.0.js').then(
            () => {
                loading$1 = false;
                sdk$1 = window.wx;
                getConfig().then(init$1, (res) => {
                    doCallbackList$1(false, res);
                });
            },
            (res) => {
                doCallbackList$1(false, res);
            }
        );
    }

    return new Promise((success, error) => {
        callbackList$1.push({
            success,
            error
        });
    })
};

var toUrl = (url, obj) => {
    let cur = url;
    let hash = '';
    let search = '';
    const searchObj = {};
    let index = url.indexOf('#');
    if (index !== -1) {
        cur = url.substr(0, index);
        hash = url.substr(index + 1);
    }

    index = cur.indexOf('?');

    if (index !== -1) {
        cur = url.substr(0, index);
        search = url.substr(index + 1);
    }

    if (search) {
        search.split('&').forEach((item) => {
            const [name, v] = item.split('=');
            searchObj[name] = v;
        });
    }

    Object.keys(obj).forEach((key) => {
        searchObj[key] = encodeURIComponent(obj[key]);
    });

    search = Object.keys(searchObj)
        .map(k => `${k}=${searchObj[k]}`)
        .join('&');

    hash = hash ? `#${hash}` : '';

    return `${cur}?${search}${hash}`
};

var redirect = (url, replace) => {
    const { location } = window;
    if (replace) {
        location.replace(url);
    } else {
        location.href = url;
    }
};

var login = ({
    needInfo,
    returnUrl = window.location.href,
    replace,
    loginUrl,
    getCode,
    wechatLoginAsWeb,
    auth
}) => {
    const url = toUrl(loginUrl, {
        returnUrl,
        replace: replace || undefined,
        auth: auth || undefined
    });

    if (wechatLoginAsWeb) {
        redirect(url);
    } else {
        getCode(url, needInfo, needInfo ? 'snsapi_userinfo' : '');
    }

    return Promise.resolve()
};

var loginStatus = ({
    loginPing, loginUrl, getCode, needInfo, wechatLoginAsWeb, auth, replace
}) =>
    loginPing({
        needInfo,
        from: wechatLoginAsWeb ? 'web' : 'wechat'
    }).then(
        () => Promise.resolve(),
        () => {
            if (!wechatLoginAsWeb) {
                login({
                    loginUrl,
                    getCode,
                    needInfo,
                    auth,
                    replace
                });
            }
            return Promise.reject()
        }
    );

var shareButton = ({
    title, desc, link, imgUrl, type, dataUrl, success
}, getSDK) => {
    getSDK().then((sdk) => {
        sdk.onMenuShareAppMessage({
            title,
            desc,
            link,
            imgUrl,
            type,
            dataUrl,
            success
        });

        sdk.onMenuShareTimeline({
            title,
            link,
            imgUrl,
            success
        });
    });
};

var geolocation = getSDK =>
    getSDK().then(
        sdk =>
            new Promise((success) => {
                sdk.getLocation({
                    type: 'wgs84',
                    success
                });
            })
    );

/* eslint-disable prefer-promise-reject-errors */
var pay = ({
    getSDK, payUrl, params, replace, returnUrl = window.location.href
}) => {
    if (payUrl) {
        redirect(
            toUrl(payUrl, {
                returnUrl,
                params: JSON.stringify(params)
            }),
            replace
        );
        return Promise.reject('link') // 外链支付
    }

    return new Promise((resolve, reject) => {
        getSDK().then((wx) => {
            const data = params.payParams;
            wx.chooseWXPay({
                timestamp: data.timeStamp,
                nonceStr: data.nonceStr,
                package: data.package,
                signType: data.signType,
                paySign: data.paySign,
                success: resolve,
                fail: reject,
                cancel: () => {
                    reject('cancel');
                }
            });
        }, reject);
    })
};

let num = 0;

var uploadFile = (
    target,
    {
        start = () => {}, success = () => {}, error = () => {}, progress = () => {}
    } = {},
    params = {},
    upload
) => {
    const input = document.createElement('input');
    input.setAttribute('type', 'file');
    input.setAttribute('style', 'position:absolute;top:0;left:0;width:100%;height:100%;opacity:0');

    const { accept } = params;
    if (accept) {
        input.setAttribute('accept', accept);
    }
    input.addEventListener('change', (e) => {
        const uuid = num++;
        start(uuid);
        upload(e.target.files[0], params, {
            success(data) {
                input.value = '';
                success(uuid, data);
            },
            progress(data) {
                progress(uuid, data);
            },
            error(err) {
                input.value = '';
                error(uuid, err);
            }
        });
    });
    target.appendChild(input);
};

var downloadImg = () => Promise.reject();

var Wechat = ({
    // 支付
    payUrl,

    // 登录
    auth,
    loginUrl,
    loginPing,
    wechatLoginAsWeb,
    logout,

    // 分享
    wechatOnShare,

    // 微信
    wechatAPPID,
    getWechatSdkConfig,

    upload
}) => {
    const getCode = getWechatCode(wechatAPPID);
    const getSDK = getWechatSDK(getWechatSdkConfig);

    return {
        back() {
            window.history.back();
        },
        loginStatus({ needInfo, replace } = {}) {
            return loginStatus({
                loginPing,
                loginUrl,
                getCode,
                needInfo,
                replace,
                wechatLoginAsWeb,
                auth
            })
        },
        login({ needInfo, returnUrl, replace } = {}) {
            return login({
                needInfo,
                returnUrl,
                replace,
                loginUrl,
                getCode,
                wechatLoginAsWeb,
                auth
            })
        },
        logout() {
            return logout().then(() => 'wechat')
        },
        pay({ params, returnUrl, replace } = {}) {
            return pay({
                getSDK,
                params,
                payUrl,
                returnUrl,
                replace
            })
        },
        shareButton(options) {
            shareButton(options, getSDK);
        },
        share() {
            if (typeof wechatOnShare === 'function') {
                wechatOnShare();
            }
        },
        open(url) {
            window.location.href = url;
        },
        geolocation() {
            return geolocation(getSDK)
        },
        previewImages(urls, index = 1) {
            getSDK().then((sdk) => {
                sdk.previewImage({
                    urls,
                    current: urls[index - 1]
                });
            });
        },
        downloadImg,
        uploadImg(target, options, params) {
            uploadFile(target, options, params, upload);
        },
        uploadVideo(target, options, params) {
            uploadFile(target, options, params, upload);
        }
    }
};

var login$1 = ({
    returnUrl = window.location.href, replace, loginUrl, auth
}) => {
    redirect(
        toUrl(loginUrl, {
            returnUrl,
            replace: replace || undefined,
            auth: auth || undefined
        })
    );
    return Promise.resolve()
};

var loginStatus$1 = loginPing => loginPing({ from: 'web' });

/* eslint-disable prefer-promise-reject-errors */
var pay$1 = ({ params, type, replace }) => {
    if (type === 1) {
        // 支付宝支付
        const { payParams } = params;
        const { alipayGateway } = payParams;
        const search = payParams.params;
        const arr = Object.keys(search).map(
            key => `${key}=${window.encodeURIComponent(search[key])}`
        );
        redirect(`${alipayGateway}?${arr.join('&')}`, replace);
        return Promise.reject('link') // 外链支付
    }
    return Promise.reject('暂不支持微信h5支付，请选择其它支付方式')
};

/**
 * 地理定位
 * @param {object}   options                    配置
 * @param {object}   options.enableHighAccuracy 是否使用高精度设备获取值，gps>wifi>ip
 * @param {object}   options.maximumAge         表示浏览器重新获取位置信息的时间间隔
 * @param {object}   options.timeout            设定请求超时时间
 * @returns
 */
var geolocation$1 = ({ enableHighAccuracy = true, maximumAge = 30000, timeout = 3000 } = {}) =>
    new Promise((resolve, reject) => {
        if ('geolocation' in navigator) {
            navigator.geolocation.getCurrentPosition(
                ({ coords }) => {
                    resolve(coords);
                },
                reject,
                {
                    enableHighAccuracy,
                    maximumAge,
                    timeout
                }
            );
        } else {
            reject(new Error('当前环境不支持定位'));
        }
    });

var Web = ({
    // 登录
    auth,
    loginUrl,
    loginPing,
    logout,

    // 分享
    webOnShare,

    // 上传
    upload
}) => ({
    back() {
        window.history.back();
    },
    loginStatus() {
        return loginStatus$1(loginPing)
    },
    login({ returnUrl, replace } = {}) {
        return login$1({
            returnUrl,
            replace,
            loginUrl,
            auth
        })
    },
    logout() {
        return logout().then(() => 'web')
    },
    pay({
        params, type, returnUrl, replace
    } = {}) {
        return pay$1({
            params,
            type,
            returnUrl,
            replace
        })
    },
    shareButton() {},
    share() {
        if (typeof webOnShare === 'function') {
            webOnShare();
        }
    },
    open(url) {
        window.open(url);
    },
    geolocation: geolocation$1,
    downloadImg,
    uploadImg(target, options, params) {
        uploadFile(target, options, params, upload);
    },
    uploadVideo(target, options, params) {
        uploadFile(target, options, params, upload);
    },
    previewImages(urls, index = 1) {
        window.open(urls[index - 1]);
    }
});

/*
 * 设备检测
 */

/* eslint-disable no-underscore-dangle */
const { userAgent } = navigator;

const isWeChat = /MicroMessenger/i.test(userAgent);
const isWeChatMiniprogram =
    isWeChat && window.__wxjs_environment === 'miniprogram';
const isAndroid = userAgent.indexOf('Android') > -1;
const isIOS = !!userAgent.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
const isAPP = /RUNEDU|RUNSCHOOL/i.test(userAgent);

/**
 * 创建iframe
 * @param  {string} src 地址
 * @return {object} frame元素
 */

var createFrame = (src) => {
    // 如果是ios10兼容伪协议
    if (isIOS) {
        src = src.replace(/^runedu:\/\/(\?&)*/, 'runedu://?&');
    }
    const frame = document.createElement('iframe');
    frame.style.cssText = 'position:absolute;left:0;top:0;width:0;height:0;visibility:hidden;';
    frame.frameBorder = '0';
    frame.src = src;
    document.body.appendChild(frame);
    return frame
};

/**
 * 简单随机数
 * @return {string} 简单的随机数
 */
var createGuid = () =>
    'xxxxxxxy'.replace(/[xy]/g, (c) => {
        /* eslint-disable no-bitwise */
        const r = (Math.random() * 16) | 0;
        const v = c === 'x' ? r : (r & 0x3) | 0x8;
        return v.toString(16)
    });

/**
 * 创建全局的临时函数
 * @param  {Function} callback      回调函数
 * @param  {Boolean}  unrestricted  不限调用次数
 * @return {string}                 创建的全局函数的函数名
 */

var createFunction = (callback, unrestricted) => {
    const name = `__RUNEDUCallback${createGuid()}_`;
    window[name] = (...args) => {
        if (typeof callback === 'function') {
            callback(...args);
        }
        if (!unrestricted) {
            delete window[name];
            callback = null;
        }
    };
    return name
};

/**
 * 获取登录信息
 * 如果用户在app登录了则返回jsonString和token，否则：
 * ————必须登录时，app先让用户登录，然后再返回jsonString和token
 * ————非必须登录，就不返回
 * 这里不保存用户登录态，调用者在回调时自行记录
 * @param  {boolean}  mustLogin 是不是必须登录
 */
var login$2 = mustLogin =>
    new Promise((resolve, reject) => {
        const name = createFunction((userInfo, token) => {
            if (token) {
                resolve(token);
            } else {
                reject(
                    new Error({
                        statusText: '无法获取token，请稍后再试'
                    })
                );
            }
        });
        createFrame(`runedu://mod=login${mustLogin ? 2 : 1}&callback=${name}`);

        // 测试
        // setTimeout(() => {
        //     window[name](null, JSON.stringify('jkfjdkjfljf'))
        // }, 1000)
    });

/**
 * 获取登录信息
 * 如果用户在app登录了则返回登录时用的code，否则：
 * ————必须登录时，app先让用户登录，然后再返回登录时用的code
 * ————非必须登录，就不返回
 * 这里不保存用户登录态，调用者在回调时自行记录
 * @param  {boolean}  mustLogin 是不是必须登录
 */
var loginCode = mustLogin =>
    new Promise((resolve, reject) => {
        const name = createFunction((code) => {
            if (code) {
                resolve(code);
            } else {
                reject(
                    new Error({
                        statusText: '无法获取Code，请稍后再试'
                    })
                );
            }
        });
        createFrame(`runedu://mod=login-code${mustLogin ? 2 : 1}&callback=${name}`);

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify('jkfjdkjfljf'))
        // }, 1000)
    });

/*
 * APP 版本
 * 目前只获取版本号的前三位，即 x.x.x
 * Android         ==> RunEduXXX?v=3.5.1.1&w=1080&h=1800&m=M355&os=Android4.4.4
 * IOS             ==> RunEduXXX?v=5.2&w=375&h=667&m=x86_64&os=IOS 8.1&b=5.2.0.0
 * IOS/Android     ==> RunSchool
 */
const { userAgent: userAgent$1 } = navigator;
const match = userAgent$1.match(/RUNEDU(\w+)\?v=(\d+)\.(\d+)(\.(\d+))*/i) || [];

const type = (match[1] || '').toLowerCase();
const v1 = Number(match[2]) || 0;
const v2 = Number(match[3]) || 0;
const v3 = Number(match[5]) || 0;
const version = [v1, v2, v3];

let isOld;
if (type) {
    if (type === 'user') {
        isOld = v1 < 5 || (v1 === 5 && version[1] <= 1);
    } else {
        isOld = v1 < 6 || (v1 === 6 && v2 === 0 && v3 === 0);
    }
} else {
    isOld = false;
}

var ua = {
    type,
    version,
    isOld
};

const byCode = (loginPing, loginWithCode) =>
    loginPing({
        from: 'runedu'
    }).then(
        data => Promise.resolve(data),
        () =>
            loginCode()
                .then(code => loginWithCode(code, true))
                .then(() =>
                    loginPing({
                        from: 'runedu'
                    })
                )
    );

const byToken = (loginPing, loginWithCode) =>
    loginPing({
        from: 'runedu'
    }).then(
        data => Promise.resolve(data),
        () =>
            login$2()
                .then(token => loginWithCode(token))
                .then(() =>
                    loginPing({
                        from: 'runedu'
                    })
                )
    );

var loginStatus$2 = (ua.isOld ? byToken : byCode);

const byCode$1 = ({ loginWithCode, returnUrl, replace }) =>
    loginCode(true)
        .then(code => loginWithCode(code, true))
        .then(() => {
            if (returnUrl) {
                redirect(returnUrl, replace);
            } else {
                window.location.reload();
            }
            return Promise.resolve()
        });

const byToken$1 = ({ loginWithCode, returnUrl, replace }) =>
    login$2(true)
        .then(token => loginWithCode(token))
        .then(() => {
            if (returnUrl) {
                redirect(returnUrl, replace);
            } else {
                window.location.reload();
            }
            return Promise.resolve()
        });

var login$3 = (ua.isOld ? byToken$1 : byCode$1);

/**
 * 支付
 * 只支持润教育 APP 4.3及以上版本
 * @param  {number}     type            支付类型，1：支付宝 2: 微信
 * @param  {object}     options         支付信息
 * @param  {function}   callback        支付回调
 * callback 接收的参数
 * @param  {string}     code            状态码 0 支付失败 1 支付成功 2 取消支付
 */

var pay$3 = (type = 1, params) =>
    new Promise((resolve, reject) => {
        const name = createFunction((code) => {
            const c = Number(JSON.parse(code));
            if (c === 1) {
                resolve();
            } else {
                reject(c);
            }
        });
        createFrame(
            `runedu://mod=pay&type=${type}&options=${encodeURIComponent(
                JSON.stringify(params)
            )}&callback=${name}`
        );

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify(1))
        // }, 3000)
    });

/* eslint-disable prefer-promise-reject-errors */
var pay$2 = ({ type, params } = {}) =>
    pay$3(type, params).then(
        () => Promise.resolve(),
        code => Promise.reject(code === 2 ? 'cancel' : undefined)
    );

/**
 * 注销
 */
var logoutSDK = () => {
    createFrame('runedu://mod=logout');
};

/**
 * 主动分享
 * @param  {object} obj 配置
 * @param  {string} obj.link        分享地址  app接口不支持&参数的网址，目前方案使用百度短网址分享
 * @param  {string} obj.title       标题
 * @param  {string} obj.desc        描述
 * @param  {string} obj.imgUrl      图片地址
 * @param  {string} obj.success     分享成功
 */

var share = ({
    title, desc, link, imgUrl, success
} = {}) => {
    const shareObj = encodeURIComponent(
        JSON.stringify({
            title, // 分享标题
            description: desc, // 分享描述
            shareUrl: link, // 分享链接
            image: imgUrl // 分享图标
        })
    );
    const name = createFunction(success);
    createFrame(`runedu://mod=share2&shareObj=${shareObj}&callback=${name}`);

    // 测试
    // setTimeout(() => {
    //     window[name]()
    // }, 1000)
};

/**
 * 被动分享
 * 通过顶部菜单中的分享按钮分享
 * 需要在head标签中加入
 * <meta name="runedu:share:switch" content="1" />
 * <meta name="runedu:share:title" content="标题" />
 * <meta name="runedu:share:description" content="分享内容" />
 * <meta name="runedu:share:image" content="图片地址" />
 * <meta name="runedu:share:site" content="分享地址" />
 * <meta name="runedu:share:callback" content="callback" />
 * content为0，表示在app顶部菜单拦不显示分享按钮
 */

/**
 * 创建meta标签
 */
const createRuneduMeta = (el, name, content) => {
    name = `runedu:share:${name}`;
    let meta = document.querySelectorAll(`meta[name="${name}"]`)[0];
    if (!meta) {
        meta = document.createElement('meta');
        meta.name = name;
        meta.content = content;
        el.appendChild(meta);
    } else {
        meta.content = content;
    }
};

var shareButton$1 = ({
    title, desc, link, imgUrl, success
} = {}) => {
    const el = document.getElementsByTagName('head')[0];
    const name = createFunction(success, true);

    createRuneduMeta(el, 'switch', 1);
    createRuneduMeta(el, 'title', title);
    createRuneduMeta(el, 'description', desc);
    createRuneduMeta(el, 'image', imgUrl);
    createRuneduMeta(el, 'site', link);
    createRuneduMeta(el, 'callback', name);

    createFrame('runedu://mod=share');
};

/**
 * 地理定位
 * 伪协议示例： runedu://mod=geolocation&callback=function
 * 接收的参数
 * @param  {jsonString} code         状态码 0 失败 1成功
 * @param  {string} lonlat           经纬度，按照英文逗号分割，例如：120,80
 */

var geolocation$2 = () =>
    new Promise((resolve, reject) => {
        const name = createFunction((code, lonlat) => {
            const c = Number(JSON.parse(code));
            const ll = JSON.parse(lonlat).split(',');
            if (c === 1) {
                resolve({
                    longitude: ll[0],
                    latitude: ll[1]
                });
            } else {
                reject();
            }
        });
        createFrame(`runedu://mod=geolocation&callback=${name}`);

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify(1), JSON.stringify('12.12,22.11'))
        // }, 1000)
    });

/**
 * 下载图片
 * 伪协议示例： runedu://mod=open&url=url
 * @param  {string}   url  图片地址(经过encodeURIComponent处理)
 */

var open = (url) => {
    createFrame(`runedu://mod=open&url=${encodeURIComponent(url)}`);
};

/**
 * 下载图片
 * 伪协议示例： runedu://mod=download-img&url=url&callback=function
 * @param  {string}   url           图片地址(经过encodeURIComponent处理)
 * 接收的参数
 * @param  {string}   code          状态码 0 本地保存失败 1 成功  2 获取不到图片
 */

var downloadImg$1 = url =>
    new Promise((resolve, reject) => {
        const name = createFunction((code) => {
            const c = Number(JSON.parse(code));
            if (c === 1) {
                resolve();
            } else {
                reject(c);
            }
        });
        createFrame(`runedu://mod=download-img&url=${encodeURIComponent(url)}&callback=${name}`);
    });

/**
 * 上传视频
 * 伪协议示例： runedu://mod=upload-video&callback=function
 * @param  {Function} callback      回调函数
 * callback接收的参数
 * @param  {jsonString} code        是否上传成功
 * @param  {object}     video       视频信息
 * @param  {string}     video.url   视频地址
 * @param  {string}     video.name  视频名称（可选）
 * @param  {string}     video.key   七牛的key
 */
var uploadVideo = type =>
    new Promise((resolve, reject) => {
        const name = createFunction((code, video) => {
            const c = Number(JSON.parse(code));
            if (c === 1) {
                resolve(JSON.parse(video));
            } else {
                reject();
            }
        });
        createFrame(`runedu://mod=upload-video&type=${type}&callback=${name}`);
    });

/**
 * 上传图片
 * 伪协议示例： runedu://mod=upload-img&callback=function
 * @param  {Function}    callback    回调函数
 * callback接收的参数
 * @param  {jsonString}  code        状态码 0 失败 1 成功
 * @param  {jsonString}  image       图片信息
 * @param  {string}      image.url   图片地址
 * @param  {string}      image.name  图片名称（可选）
 * @param  {string}      image.key   七牛的key
 */

var uploadImg = type =>
    new Promise((resolve, reject) => {
        const name = createFunction((code, image) => {
            const c = Number(JSON.parse(code));
            if (c === 1) {
                resolve(JSON.parse(image));
            } else {
                reject();
            }
        });
        createFrame(`runedu://mod=upload-img&type=${type}&callback=${name}`);
    });

let num$1 = 0;

var upload = (
    target,
    { start = () => {}, success = () => {}, error = () => {} } = {},
    { type = 0 } = {},
    upload
) => {
    const el = document.createElement('div');
    el.setAttribute('style', 'position:absolute;top:0;left:0;width:100%;height:100%;opacity:0');
    el.addEventListener('click', () => {
        const uuid = num$1++;
        start(uuid);
        upload(type).then(
            (data) => {
                success(uuid, data);
            },
            (res) => {
                error(uuid, res);
            }
        );
    });
    target.appendChild(el);
};

/**
 * 润教育APP的js sdk
 */

var APP = ({ loginPing, loginWithCode, logout }) => ({
    back() {
        window.history.back();
    },
    loginStatus() {
        return loginStatus$2(loginPing, loginWithCode)
    },
    login({ returnUrl, replace } = {}) {
        return login$3({ loginWithCode, returnUrl, replace })
    },
    logout() {
        return logout().then(() => {
            logoutSDK();
            return 'runedu'
        })
    },
    pay: pay$2,
    shareButton: shareButton$1,
    share,
    geolocation: geolocation$2,
    open,
    uploadImg(target, options, params) {
        upload(target, options, params, uploadImg);
    },
    uploadVideo(target, options, params) {
        upload(target, options, params, uploadVideo);
    },
    downloadImg: downloadImg$1,
    previewImages(urls, index = 1) {
        open(urls[index - 1]);
    }
});

const target = 'wechat-miniprogram';

var WeChatMiniprogram = ({
    // 登录
    loginPing,
    loginUrlMiniProgram,
    logout,
    miniProgramWidow,

    // 微信
    getWechatSdkConfig,

    upload
}) => {
    const getSDK = getWechatSDK(getWechatSdkConfig);

    return {
        back() {
            getSDK().then((sdk) => {
                sdk.miniProgram.navigateBack();
            });
        },
        loginStatus() {
            return loginPing({ from: target })
        },
        login() {
            return getSDK().then(
                sdk =>
                    new Promise((success, fail) => {
                        sdk.miniProgram.navigateTo({
                            url: loginUrlMiniProgram,
                            success,
                            fail
                        });
                    })
            )
        },
        logout() {
            return logout().then(() => target)
        },
        pay() {
            return Promise.reject(new Error('微信小程序内嵌网页暂不支持支付'))
        },
        shareButton() {
            // 暂不处理
        },
        share() {
            // 暂不处理
        },
        open(url, type) {
            return getSDK().then(
                sdk =>
                    new Promise((success, fail) => {
                        if (type === 'switch') {
                            sdk.miniProgram.switchTab({
                                url,
                                success,
                                fail
                            });
                        } else if (type === 'page') {
                            sdk.miniProgram.navigateTo({
                                url,
                                success,
                                fail
                            });
                        } else {
                            sdk.miniProgram.navigateTo({
                                url: `${miniProgramWidow}?url=${encodeURIComponent(url)}`,
                                success,
                                fail
                            });
                        }
                    })
            )
        },
        geolocation() {
            return getSDK().then(
                sdk =>
                    new Promise((success) => {
                        sdk.getLocation({
                            type: 'wgs84',
                            success
                        });
                    })
            )
        },
        previewImages(urls, index = 1) {
            getSDK().then((sdk) => {
                // 待测试
                sdk.previewImage({
                    urls,
                    current: urls[index - 1]
                });
            });
        },
        downloadImg,
        uploadImg(target, options, params) {
            uploadFile(target, options, params, upload);
        },
        uploadVideo(target, options, params) {
            uploadFile(target, options, params, upload);
        }
    }
};

var formatPayParams = ({ params = {}, type, returnUrl = window.location.href }) => {
    let thirdPayType;
    let r;

    if (isAPP) {
        thirdPayType = type === 1 ? 4 : 2;
    } else if (type === 2) {
        thirdPayType = 1;
    } else {
        thirdPayType = 3;
        r = returnUrl;
    }

    return Object.assign(params, {
        thirdPayType,
        returnUrl: r
    })
};

var index = (options = {}) => {
    let SDK;

    if (isAPP) {
        SDK = APP;
    } else if (isWeChatMiniprogram) {
        SDK = WeChatMiniprogram;
    } else if (isWeChat) {
        SDK = Wechat;
    } else {
        SDK = Web;
    }

    const sdk = SDK(options);
    const { talkingdataAPPID, baidutongjiAPPID } = options;

    sdk.formatPayParams = formatPayParams;

    if (talkingdataAPPID) {
        sdk.report = TD(talkingdataAPPID);
    }

    if (baidutongjiAPPID) {
        BDTJ(baidutongjiAPPID);
    }

    return sdk
};

export default index;
