/*!
 * runedu-js-sdk.js v0.34.2
 */
(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
	typeof define === 'function' && define.amd ? define(factory) :
	(global.RUNEDU_JS_SDK = factory());
}(this, (function () { 'use strict';

/**
 * 创建script
 * @param  {string}     src 地址
 * @param  {function}   resolve 加载成功回调
 * @param  {function}   reject  加载失败回调
 * @return {object}     promise
 */

var createScript = function (src) { return new Promise(function (resolve, reject) {
        var el = document.createElement('script');
        el.src = src;
        el.onload = function () {
            resolve(el);
            el = null;
        };
        el.onerror = function (err) {
            reject(err);
            el.parentNode.removeChild(el);
            el = null;
        };
        document.getElementsByTagName('body')[0].appendChild(el);
    }); };

// 百度统计
var BDTJ = function (APPID) {
    createScript(("//hm.baidu.com/hm.js?" + APPID));
};

var sdk;
var loading = false;
var callbackList = [];

var doCallbackList = function (bl, res) {
    if (bl) {
        callbackList.forEach(function (ref) {
            var resolve = ref.resolve;

            resolve(sdk);
        });
    } else {
        callbackList.forEach(function (ref) {
            var reject = ref.reject;

            reject(res);
        });
    }
    loading = false;
    callbackList = [];
};

var init = function (APPID) { return function () {
    if (sdk) {
        return Promise.resolve(sdk)
    }

    if (!loading) {
        loading = true;
        createScript(("https://jic.talkingdata.com/app/h5/v1?appid=" + APPID + "&vn=v3")).then(
            function () {
                sdk = window.TDAPP;
                doCallbackList(true);
            },
            function (res) {
                doCallbackList(false, res);
            }
        );
    }

    return new Promise(function (resolve, reject) {
        callbackList.push({
            resolve: resolve,
            reject: reject
        });
    })
}; };

var TD = function (APPID) {
    var getSDK = init(APPID);
    return function () {
        var reset = [], len = arguments.length;
        while ( len-- ) reset[ len ] = arguments[ len ];

        getSDK().then(function (sdk) {
            sdk.onEvent.apply(sdk, reset);
        });
    }
};

var getWechatCode = function (appid) { return function (returnUrl, needInfo, state) {
    if ( state === void 0 ) state = '';

    var options = {
        appid: appid,
        redirect_uri: window.encodeURIComponent(returnUrl),
        scope: needInfo ? 'snsapi_userinfo' : 'snsapi_base',
        response_type: 'code',
        state: state
    };

    var search = Object.keys(options)
        .map(function (item) { return (item + "=" + (options[item])); })
        .join('&');

    window.location.href = "https://open.weixin.qq.com/connect/oauth2/authorize?" + search + "#wechat_redirect";
}; };

/**
 * 获取微信jssdk引用
 * http://mp.weixin.qq.com/wiki/7/aaa137b55fb2e0456bf8dd9148dd613f.html
 */

var loading$1 = false;
var sdk$1 = window.wx; // 可能被全局引入了
var callbackList$1 = [];

var doCallbackList$1 = function (bl, res) {
    if (bl) {
        callbackList$1.forEach(function (ref) {
            var success = ref.success;

            success(sdk$1);
        });
    } else {
        callbackList$1.forEach(function (ref) {
            var error = ref.error;

            error(res);
        });
    }
    loading$1 = false;
    callbackList$1 = [];
};

var init$1 = function (config) {
    // 需要使用的JS接口列表
    var jsApiList = [
        'onMenuShareTimeline',
        'onMenuShareAppMessage',
        'onMenuShareQQ',
        'onMenuShareWeibo',
        'onMenuShareQZone',
        'startRecord',
        'stopRecord',
        'onVoiceRecordEnd',
        'playVoice',
        'pauseVoice',
        'stopVoice',
        'onVoicePlayEnd',
        'uploadVoice',
        'downloadVoice',
        'chooseImage',
        'previewImage',
        'uploadImage',
        'downloadImage',
        'translateVoice',
        'getNetworkType',
        'openLocation',
        'getLocation',
        'hideOptionMenu',
        'showOptionMenu',
        'hideMenuItems',
        'showMenuItems',
        'hideAllNonBaseMenuItem',
        'showAllNonBaseMenuItem',
        'closeWindow',
        'scanQRCode',
        'chooseWXPay',
        'openProductSpecificView',
        'addCard',
        'chooseCard',
        'openCard'
    ];

    sdk$1.config({
        debug: process.env.NODE_ENV === 'development', // 开启调试模式。
        appId: config.appid, // 必填，公众号的唯一标识
        timestamp: config.timestamp, // 必填，生成签名的时间戳
        nonceStr: config.noncestr, // 必填，生成签名的随机串
        signature: config.signature, // 必填，签名，见附录1
        jsApiList: jsApiList // 必填，需要使用的JS接口列表，所有JS接口列表见附录2
    });

    sdk$1.ready(function () {
        doCallbackList$1(true);
    });

    sdk$1.error(function (err) {
        doCallbackList$1(false, err);
    });
};

var getWechatSDK = function (getConfig) { return function () {
    if (sdk$1) {
        return Promise.resolve(sdk$1)
    }

    if (!loading$1) {
        loading$1 = true;
        createScript('//res.wx.qq.com/open/js/jweixin-1.3.0.js').then(
            function () {
                loading$1 = false;
                sdk$1 = window.wx;
                getConfig().then(init$1, function (res) {
                    doCallbackList$1(false, res);
                });
            },
            function (res) {
                doCallbackList$1(false, res);
            }
        );
    }

    return new Promise(function (success, error) {
        callbackList$1.push({
            success: success,
            error: error
        });
    })
}; };

var toUrl = function (url, obj) {
    var cur = url;
    var hash = '';
    var search = '';
    var searchObj = {};
    var index = url.indexOf('#');
    if (index !== -1) {
        cur = url.substr(0, index);
        hash = url.substr(index + 1);
    }

    index = cur.indexOf('?');

    if (index !== -1) {
        cur = url.substr(0, index);
        search = url.substr(index + 1);
    }

    if (search) {
        search.split('&').forEach(function (item) {
            var ref = item.split('=');
            var name = ref[0];
            var v = ref[1];
            searchObj[name] = v;
        });
    }

    Object.keys(obj).forEach(function (key) {
        searchObj[key] = encodeURIComponent(obj[key]);
    });

    search = Object.keys(searchObj)
        .map(function (k) { return (k + "=" + (searchObj[k])); })
        .join('&');

    hash = hash ? ("#" + hash) : '';

    return (cur + "?" + search + hash)
};

var redirect = function (url, replace) {
    var location = window.location;
    if (replace) {
        location.replace(url);
    } else {
        location.href = url;
    }
};

var login = function (ref) {
    var needInfo = ref.needInfo;
    var returnUrl = ref.returnUrl; if ( returnUrl === void 0 ) returnUrl = window.location.href;
    var replace = ref.replace;
    var loginUrl = ref.loginUrl;
    var getCode = ref.getCode;
    var wechatLoginAsWeb = ref.wechatLoginAsWeb;
    var auth = ref.auth;

    var url = toUrl(loginUrl, {
        returnUrl: returnUrl,
        replace: replace || undefined,
        auth: auth || undefined
    });

    if (wechatLoginAsWeb) {
        redirect(url);
    } else {
        getCode(url, needInfo, needInfo ? 'snsapi_userinfo' : '');
    }

    return Promise.resolve()
};

var loginStatus = function (ref) {
        var loginPing = ref.loginPing;
        var loginUrl = ref.loginUrl;
        var getCode = ref.getCode;
        var needInfo = ref.needInfo;
        var wechatLoginAsWeb = ref.wechatLoginAsWeb;
        var auth = ref.auth;
        var replace = ref.replace;

        return loginPing({
        needInfo: needInfo,
        from: wechatLoginAsWeb ? 'web' : 'wechat'
    }).then(
        function () { return Promise.resolve(); },
        function () {
            if (!wechatLoginAsWeb) {
                login({
                    loginUrl: loginUrl,
                    getCode: getCode,
                    needInfo: needInfo,
                    auth: auth,
                    replace: replace
                });
            }
            return Promise.reject()
        }
    );
};

var shareButton = function (ref, getSDK) {
    var title = ref.title;
    var desc = ref.desc;
    var link = ref.link;
    var imgUrl = ref.imgUrl;
    var type = ref.type;
    var dataUrl = ref.dataUrl;
    var success = ref.success;

    getSDK().then(function (sdk) {
        sdk.onMenuShareAppMessage({
            title: title,
            desc: desc,
            link: link,
            imgUrl: imgUrl,
            type: type,
            dataUrl: dataUrl,
            success: success
        });

        sdk.onMenuShareTimeline({
            title: title,
            link: link,
            imgUrl: imgUrl,
            success: success
        });
    });
};

var geolocation = function (getSDK) { return getSDK().then(
        function (sdk) { return new Promise(function (success) {
                sdk.getLocation({
                    type: 'wgs84',
                    success: success
                });
            }); }
    ); };

/* eslint-disable prefer-promise-reject-errors */
var pay = function (ref) {
    var getSDK = ref.getSDK;
    var payUrl = ref.payUrl;
    var params = ref.params;
    var replace = ref.replace;
    var returnUrl = ref.returnUrl; if ( returnUrl === void 0 ) returnUrl = window.location.href;

    if (payUrl) {
        redirect(
            toUrl(payUrl, {
                returnUrl: returnUrl,
                params: JSON.stringify(params)
            }),
            replace
        );
        return Promise.reject('link') // 外链支付
    }

    return new Promise(function (resolve, reject) {
        getSDK().then(function (wx) {
            var data = params.payParams;
            wx.chooseWXPay({
                timestamp: data.timeStamp,
                nonceStr: data.nonceStr,
                package: data.package,
                signType: data.signType,
                paySign: data.paySign,
                success: resolve,
                fail: reject,
                cancel: function () {
                    reject('cancel');
                }
            });
        }, reject);
    })
};

var num = 0;

var uploadFile = function (
    target,
    ref,
    params,
    upload
) {
    if ( ref === void 0 ) ref = {};
    var start = ref.start; if ( start === void 0 ) start = function () {};
    var success = ref.success; if ( success === void 0 ) success = function () {};
    var error = ref.error; if ( error === void 0 ) error = function () {};
    var progress = ref.progress; if ( progress === void 0 ) progress = function () {};
    if ( params === void 0 ) params = {};

    var input = document.createElement('input');
    input.setAttribute('type', 'file');
    input.setAttribute('style', 'position:absolute;top:0;left:0;width:100%;height:100%;opacity:0');

    var accept = params.accept;
    if (accept) {
        input.setAttribute('accept', accept);
    }
    input.addEventListener('change', function (e) {
        var uuid = num++;
        start(uuid);
        upload(e.target.files[0], params, {
            success: function success$1(data) {
                input.value = '';
                success(uuid, data);
            },
            progress: function progress$1(data) {
                progress(uuid, data);
            },
            error: function error$1(err) {
                input.value = '';
                error(uuid, err);
            }
        });
    });
    target.appendChild(input);
};

var downloadImg = function () { return Promise.reject(); };

var Wechat = function (ref) {
    var payUrl = ref.payUrl;
    var auth = ref.auth;
    var loginUrl = ref.loginUrl;
    var loginPing = ref.loginPing;
    var wechatLoginAsWeb = ref.wechatLoginAsWeb;
    var logout = ref.logout;
    var wechatOnShare = ref.wechatOnShare;
    var wechatAPPID = ref.wechatAPPID;
    var getWechatSdkConfig = ref.getWechatSdkConfig;
    var upload = ref.upload;

    var getCode = getWechatCode(wechatAPPID);
    var getSDK = getWechatSDK(getWechatSdkConfig);

    return {
        back: function back() {
            window.history.back();
        },
        loginStatus: function loginStatus$1(ref) {
            if ( ref === void 0 ) ref = {};
            var needInfo = ref.needInfo;
            var replace = ref.replace;

            return loginStatus({
                loginPing: loginPing,
                loginUrl: loginUrl,
                getCode: getCode,
                needInfo: needInfo,
                replace: replace,
                wechatLoginAsWeb: wechatLoginAsWeb,
                auth: auth
            })
        },
        login: function login$1(ref) {
            if ( ref === void 0 ) ref = {};
            var needInfo = ref.needInfo;
            var returnUrl = ref.returnUrl;
            var replace = ref.replace;

            return login({
                needInfo: needInfo,
                returnUrl: returnUrl,
                replace: replace,
                loginUrl: loginUrl,
                getCode: getCode,
                wechatLoginAsWeb: wechatLoginAsWeb,
                auth: auth
            })
        },
        logout: function logout$1() {
            return logout().then(function () { return 'wechat'; })
        },
        pay: function pay$1(ref) {
            if ( ref === void 0 ) ref = {};
            var params = ref.params;
            var returnUrl = ref.returnUrl;
            var replace = ref.replace;

            return pay({
                getSDK: getSDK,
                params: params,
                payUrl: payUrl,
                returnUrl: returnUrl,
                replace: replace
            })
        },
        shareButton: function shareButton$1(options) {
            shareButton(options, getSDK);
        },
        share: function share() {
            if (typeof wechatOnShare === 'function') {
                wechatOnShare();
            }
        },
        open: function open(url) {
            window.location.href = url;
        },
        geolocation: function geolocation$1() {
            return geolocation(getSDK)
        },
        previewImages: function previewImages(urls, index) {
            if ( index === void 0 ) index = 1;

            getSDK().then(function (sdk) {
                sdk.previewImage({
                    urls: urls,
                    current: urls[index - 1]
                });
            });
        },
        downloadImg: downloadImg,
        uploadImg: function uploadImg(target, options, params) {
            uploadFile(target, options, params, upload);
        },
        uploadVideo: function uploadVideo(target, options, params) {
            uploadFile(target, options, params, upload);
        }
    }
};

var login$1 = function (ref) {
    var returnUrl = ref.returnUrl; if ( returnUrl === void 0 ) returnUrl = window.location.href;
    var replace = ref.replace;
    var loginUrl = ref.loginUrl;
    var auth = ref.auth;

    redirect(
        toUrl(loginUrl, {
            returnUrl: returnUrl,
            replace: replace || undefined,
            auth: auth || undefined
        })
    );
    return Promise.resolve()
};

var loginStatus$1 = function (loginPing) { return loginPing({ from: 'web' }); };

/* eslint-disable prefer-promise-reject-errors */
var pay$1 = function (ref) {
    var params = ref.params;
    var type = ref.type;
    var replace = ref.replace;

    if (type === 1) {
        // 支付宝支付
        var payParams = params.payParams;
        var alipayGateway = payParams.alipayGateway;
        var search = payParams.params;
        var arr = Object.keys(search).map(
            function (key) { return (key + "=" + (window.encodeURIComponent(search[key]))); }
        );
        redirect((alipayGateway + "?" + (arr.join('&'))), replace);
        return Promise.reject('link') // 外链支付
    }
    return Promise.reject('暂不支持微信h5支付，请选择其它支付方式')
};

/**
 * 地理定位
 * @param {object}   options                    配置
 * @param {object}   options.enableHighAccuracy 是否使用高精度设备获取值，gps>wifi>ip
 * @param {object}   options.maximumAge         表示浏览器重新获取位置信息的时间间隔
 * @param {object}   options.timeout            设定请求超时时间
 * @returns
 */
var geolocation$1 = function (ref) {
        if ( ref === void 0 ) ref = {};
        var enableHighAccuracy = ref.enableHighAccuracy; if ( enableHighAccuracy === void 0 ) enableHighAccuracy = true;
        var maximumAge = ref.maximumAge; if ( maximumAge === void 0 ) maximumAge = 30000;
        var timeout = ref.timeout; if ( timeout === void 0 ) timeout = 3000;

        return new Promise(function (resolve, reject) {
        if ('geolocation' in navigator) {
            navigator.geolocation.getCurrentPosition(
                function (ref) {
                    var coords = ref.coords;

                    resolve(coords);
                },
                reject,
                {
                    enableHighAccuracy: enableHighAccuracy,
                    maximumAge: maximumAge,
                    timeout: timeout
                }
            );
        } else {
            reject(new Error('当前环境不支持定位'));
        }
    });
};

var Web = function (ref) {
    var auth = ref.auth;
    var loginUrl = ref.loginUrl;
    var loginPing = ref.loginPing;
    var logout = ref.logout;
    var webOnShare = ref.webOnShare;
    var upload = ref.upload;

    return ({
    back: function back() {
        window.history.back();
    },
    loginStatus: function loginStatus$1$$1() {
        return loginStatus$1(loginPing)
    },
    login: function login$1$$1(ref) {
        if ( ref === void 0 ) ref = {};
        var returnUrl = ref.returnUrl;
        var replace = ref.replace;

        return login$1({
            returnUrl: returnUrl,
            replace: replace,
            loginUrl: loginUrl,
            auth: auth
        })
    },
    logout: function logout$1() {
        return logout().then(function () { return 'web'; })
    },
    pay: function pay$1$$1(ref) {
        if ( ref === void 0 ) ref = {};
        var params = ref.params;
        var type = ref.type;
        var returnUrl = ref.returnUrl;
        var replace = ref.replace;

        return pay$1({
            params: params,
            type: type,
            returnUrl: returnUrl,
            replace: replace
        })
    },
    shareButton: function shareButton() {},
    share: function share() {
        if (typeof webOnShare === 'function') {
            webOnShare();
        }
    },
    open: function open(url) {
        window.open(url);
    },
    geolocation: geolocation$1,
    downloadImg: downloadImg,
    uploadImg: function uploadImg(target, options, params) {
        uploadFile(target, options, params, upload);
    },
    uploadVideo: function uploadVideo(target, options, params) {
        uploadFile(target, options, params, upload);
    },
    previewImages: function previewImages(urls, index) {
        if ( index === void 0 ) index = 1;

        window.open(urls[index - 1]);
    }
});
};

/*
 * 设备检测
 */

/* eslint-disable no-underscore-dangle */
var userAgent = navigator.userAgent;

var isWeChat = /MicroMessenger/i.test(userAgent);
var isWeChatMiniprogram =
    isWeChat && window.__wxjs_environment === 'miniprogram';
var isAndroid = userAgent.indexOf('Android') > -1;
var isIOS = !!userAgent.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
var isAPP = /RUNEDU|RUNSCHOOL/i.test(userAgent);

/**
 * 创建iframe
 * @param  {string} src 地址
 * @return {object} frame元素
 */

var createFrame = function (src) {
    // 如果是ios10兼容伪协议
    if (isIOS) {
        src = src.replace(/^runedu:\/\/(\?&)*/, 'runedu://?&');
    }
    var frame = document.createElement('iframe');
    frame.style.cssText = 'position:absolute;left:0;top:0;width:0;height:0;visibility:hidden;';
    frame.frameBorder = '0';
    frame.src = src;
    document.body.appendChild(frame);
    return frame
};

/**
 * 简单随机数
 * @return {string} 简单的随机数
 */
var createGuid = function () { return 'xxxxxxxy'.replace(/[xy]/g, function (c) {
        /* eslint-disable no-bitwise */
        var r = (Math.random() * 16) | 0;
        var v = c === 'x' ? r : (r & 0x3) | 0x8;
        return v.toString(16)
    }); };

/**
 * 创建全局的临时函数
 * @param  {Function} callback      回调函数
 * @param  {Boolean}  unrestricted  不限调用次数
 * @return {string}                 创建的全局函数的函数名
 */

var createFunction = function (callback, unrestricted) {
    var name = "__RUNEDUCallback" + (createGuid()) + "_";
    window[name] = function () {
        var args = [], len = arguments.length;
        while ( len-- ) args[ len ] = arguments[ len ];

        if (typeof callback === 'function') {
            callback.apply(void 0, args);
        }
        if (!unrestricted) {
            delete window[name];
            callback = null;
        }
    };
    return name
};

/**
 * 获取登录信息
 * 如果用户在app登录了则返回jsonString和token，否则：
 * ————必须登录时，app先让用户登录，然后再返回jsonString和token
 * ————非必须登录，就不返回
 * 这里不保存用户登录态，调用者在回调时自行记录
 * @param  {boolean}  mustLogin 是不是必须登录
 */
var login$2 = function (mustLogin) { return new Promise(function (resolve, reject) {
        var name = createFunction(function (userInfo, token) {
            if (token) {
                resolve(token);
            } else {
                reject(
                    new Error({
                        statusText: '无法获取token，请稍后再试'
                    })
                );
            }
        });
        createFrame(("runedu://mod=login" + (mustLogin ? 2 : 1) + "&callback=" + name));

        // 测试
        // setTimeout(() => {
        //     window[name](null, JSON.stringify('jkfjdkjfljf'))
        // }, 1000)
    }); };

/**
 * 获取登录信息
 * 如果用户在app登录了则返回登录时用的code，否则：
 * ————必须登录时，app先让用户登录，然后再返回登录时用的code
 * ————非必须登录，就不返回
 * 这里不保存用户登录态，调用者在回调时自行记录
 * @param  {boolean}  mustLogin 是不是必须登录
 */
var loginCode = function (mustLogin) { return new Promise(function (resolve, reject) {
        var name = createFunction(function (code) {
            if (code) {
                resolve(code);
            } else {
                reject(
                    new Error({
                        statusText: '无法获取Code，请稍后再试'
                    })
                );
            }
        });
        createFrame(("runedu://mod=login-code" + (mustLogin ? 2 : 1) + "&callback=" + name));

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify('jkfjdkjfljf'))
        // }, 1000)
    }); };

/*
 * APP 版本
 * 目前只获取版本号的前三位，即 x.x.x
 * Android         ==> RunEduXXX?v=3.5.1.1&w=1080&h=1800&m=M355&os=Android4.4.4
 * IOS             ==> RunEduXXX?v=5.2&w=375&h=667&m=x86_64&os=IOS 8.1&b=5.2.0.0
 * IOS/Android     ==> RunSchool
 */
var userAgent$1 = navigator.userAgent;
var match = userAgent$1.match(/RUNEDU(\w+)\?v=(\d+)\.(\d+)(\.(\d+))*/i) || [];

var type = (match[1] || '').toLowerCase();
var v1 = Number(match[2]) || 0;
var v2 = Number(match[3]) || 0;
var v3 = Number(match[5]) || 0;
var version = [v1, v2, v3];

var isOld;
if (type) {
    if (type === 'user') {
        isOld = v1 < 5 || (v1 === 5 && version[1] <= 1);
    } else {
        isOld = v1 < 6 || (v1 === 6 && v2 === 0 && v3 === 0);
    }
} else {
    isOld = false;
}

var ua = {
    type: type,
    version: version,
    isOld: isOld
};

var byCode = function (loginPing, loginWithCode) { return loginPing({
        from: 'runedu'
    }).then(
        function (data) { return Promise.resolve(data); },
        function () { return loginCode()
                .then(function (code) { return loginWithCode(code, true); })
                .then(function () { return loginPing({
                        from: 'runedu'
                    }); }
                ); }
    ); };

var byToken = function (loginPing, loginWithCode) { return loginPing({
        from: 'runedu'
    }).then(
        function (data) { return Promise.resolve(data); },
        function () { return login$2()
                .then(function (token) { return loginWithCode(token); })
                .then(function () { return loginPing({
                        from: 'runedu'
                    }); }
                ); }
    ); };

var loginStatus$2 = (ua.isOld ? byToken : byCode);

var byCode$1 = function (ref) {
        var loginWithCode = ref.loginWithCode;
        var returnUrl = ref.returnUrl;
        var replace = ref.replace;

        return loginCode(true)
        .then(function (code) { return loginWithCode(code, true); })
        .then(function () {
            if (returnUrl) {
                redirect(returnUrl, replace);
            } else {
                window.location.reload();
            }
            return Promise.resolve()
        });
};

var byToken$1 = function (ref) {
        var loginWithCode = ref.loginWithCode;
        var returnUrl = ref.returnUrl;
        var replace = ref.replace;

        return login$2(true)
        .then(function (token) { return loginWithCode(token); })
        .then(function () {
            if (returnUrl) {
                redirect(returnUrl, replace);
            } else {
                window.location.reload();
            }
            return Promise.resolve()
        });
};

var login$3 = (ua.isOld ? byToken$1 : byCode$1);

/**
 * 支付
 * 只支持润教育 APP 4.3及以上版本
 * @param  {number}     type            支付类型，1：支付宝 2: 微信
 * @param  {object}     options         支付信息
 * @param  {function}   callback        支付回调
 * callback 接收的参数
 * @param  {string}     code            状态码 0 支付失败 1 支付成功 2 取消支付
 */

var pay$3 = function (type, params) {
        if ( type === void 0 ) type = 1;

        return new Promise(function (resolve, reject) {
        var name = createFunction(function (code) {
            var c = Number(JSON.parse(code));
            if (c === 1) {
                resolve();
            } else {
                reject(c);
            }
        });
        createFrame(
            ("runedu://mod=pay&type=" + type + "&options=" + (encodeURIComponent(
                JSON.stringify(params)
            )) + "&callback=" + name)
        );

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify(1))
        // }, 3000)
    });
};

/* eslint-disable prefer-promise-reject-errors */
var pay$2 = function (ref) {
        if ( ref === void 0 ) ref = {};
        var type = ref.type;
        var params = ref.params;

        return pay$3(type, params).then(
        function () { return Promise.resolve(); },
        function (code) { return Promise.reject(code === 2 ? 'cancel' : undefined); }
    );
};

/**
 * 注销
 */
var logoutSDK = function () {
    createFrame('runedu://mod=logout');
};

/**
 * 主动分享
 * @param  {object} obj 配置
 * @param  {string} obj.link        分享地址  app接口不支持&参数的网址，目前方案使用百度短网址分享
 * @param  {string} obj.title       标题
 * @param  {string} obj.desc        描述
 * @param  {string} obj.imgUrl      图片地址
 * @param  {string} obj.success     分享成功
 */

var share = function (ref) {
    if ( ref === void 0 ) ref = {};
    var title = ref.title;
    var desc = ref.desc;
    var link = ref.link;
    var imgUrl = ref.imgUrl;
    var success = ref.success;

    var shareObj = encodeURIComponent(
        JSON.stringify({
            title: title, // 分享标题
            description: desc, // 分享描述
            shareUrl: link, // 分享链接
            image: imgUrl // 分享图标
        })
    );
    var name = createFunction(success);
    createFrame(("runedu://mod=share2&shareObj=" + shareObj + "&callback=" + name));

    // 测试
    // setTimeout(() => {
    //     window[name]()
    // }, 1000)
};

/**
 * 被动分享
 * 通过顶部菜单中的分享按钮分享
 * 需要在head标签中加入
 * <meta name="runedu:share:switch" content="1" />
 * <meta name="runedu:share:title" content="标题" />
 * <meta name="runedu:share:description" content="分享内容" />
 * <meta name="runedu:share:image" content="图片地址" />
 * <meta name="runedu:share:site" content="分享地址" />
 * <meta name="runedu:share:callback" content="callback" />
 * content为0，表示在app顶部菜单拦不显示分享按钮
 */

/**
 * 创建meta标签
 */
var createRuneduMeta = function (el, name, content) {
    name = "runedu:share:" + name;
    var meta = document.querySelectorAll(("meta[name=\"" + name + "\"]"))[0];
    if (!meta) {
        meta = document.createElement('meta');
        meta.name = name;
        meta.content = content;
        el.appendChild(meta);
    } else {
        meta.content = content;
    }
};

var shareButton$1 = function (ref) {
    if ( ref === void 0 ) ref = {};
    var title = ref.title;
    var desc = ref.desc;
    var link = ref.link;
    var imgUrl = ref.imgUrl;
    var success = ref.success;

    var el = document.getElementsByTagName('head')[0];
    var name = createFunction(success, true);

    createRuneduMeta(el, 'switch', 1);
    createRuneduMeta(el, 'title', title);
    createRuneduMeta(el, 'description', desc);
    createRuneduMeta(el, 'image', imgUrl);
    createRuneduMeta(el, 'site', link);
    createRuneduMeta(el, 'callback', name);

    createFrame('runedu://mod=share');
};

/**
 * 地理定位
 * 伪协议示例： runedu://mod=geolocation&callback=function
 * 接收的参数
 * @param  {jsonString} code         状态码 0 失败 1成功
 * @param  {string} lonlat           经纬度，按照英文逗号分割，例如：120,80
 */

var geolocation$2 = function () { return new Promise(function (resolve, reject) {
        var name = createFunction(function (code, lonlat) {
            var c = Number(JSON.parse(code));
            var ll = JSON.parse(lonlat).split(',');
            if (c === 1) {
                resolve({
                    longitude: ll[0],
                    latitude: ll[1]
                });
            } else {
                reject();
            }
        });
        createFrame(("runedu://mod=geolocation&callback=" + name));

        // 测试
        // setTimeout(() => {
        //     window[name](JSON.stringify(1), JSON.stringify('12.12,22.11'))
        // }, 1000)
    }); };

/**
 * 下载图片
 * 伪协议示例： runedu://mod=open&url=url
 * @param  {string}   url  图片地址(经过encodeURIComponent处理)
 */

var open = function (url) {
    createFrame(("runedu://mod=open&url=" + (encodeURIComponent(url))));
};

/**
 * 下载图片
 * 伪协议示例： runedu://mod=download-img&url=url&callback=function
 * @param  {string}   url           图片地址(经过encodeURIComponent处理)
 * 接收的参数
 * @param  {string}   code          状态码 0 本地保存失败 1 成功  2 获取不到图片
 */

var downloadImg$1 = function (url) { return new Promise(function (resolve, reject) {
        var name = createFunction(function (code) {
            var c = Number(JSON.parse(code));
            if (c === 1) {
                resolve();
            } else {
                reject(c);
            }
        });
        createFrame(("runedu://mod=download-img&url=" + (encodeURIComponent(url)) + "&callback=" + name));
    }); };

/**
 * 上传视频
 * 伪协议示例： runedu://mod=upload-video&callback=function
 * @param  {Function} callback      回调函数
 * callback接收的参数
 * @param  {jsonString} code        是否上传成功
 * @param  {object}     video       视频信息
 * @param  {string}     video.url   视频地址
 * @param  {string}     video.name  视频名称（可选）
 * @param  {string}     video.key   七牛的key
 */
var uploadVideo = function (type) { return new Promise(function (resolve, reject) {
        var name = createFunction(function (code, video) {
            var c = Number(JSON.parse(code));
            if (c === 1) {
                resolve(JSON.parse(video));
            } else {
                reject();
            }
        });
        createFrame(("runedu://mod=upload-video&type=" + type + "&callback=" + name));
    }); };

/**
 * 上传图片
 * 伪协议示例： runedu://mod=upload-img&callback=function
 * @param  {Function}    callback    回调函数
 * callback接收的参数
 * @param  {jsonString}  code        状态码 0 失败 1 成功
 * @param  {jsonString}  image       图片信息
 * @param  {string}      image.url   图片地址
 * @param  {string}      image.name  图片名称（可选）
 * @param  {string}      image.key   七牛的key
 */

var uploadImg = function (type) { return new Promise(function (resolve, reject) {
        var name = createFunction(function (code, image) {
            var c = Number(JSON.parse(code));
            if (c === 1) {
                resolve(JSON.parse(image));
            } else {
                reject();
            }
        });
        createFrame(("runedu://mod=upload-img&type=" + type + "&callback=" + name));
    }); };

var num$1 = 0;

var upload = function (
    target,
    ref,
    ref$1,
    upload
) {
    if ( ref === void 0 ) ref = {};
    var start = ref.start; if ( start === void 0 ) start = function () {};
    var success = ref.success; if ( success === void 0 ) success = function () {};
    var error = ref.error; if ( error === void 0 ) error = function () {};
    if ( ref$1 === void 0 ) ref$1 = {};
    var type = ref$1.type; if ( type === void 0 ) type = 0;

    var el = document.createElement('div');
    el.setAttribute('style', 'position:absolute;top:0;left:0;width:100%;height:100%;opacity:0');
    el.addEventListener('click', function () {
        var uuid = num$1++;
        start(uuid);
        upload(type).then(
            function (data) {
                success(uuid, data);
            },
            function (res) {
                error(uuid, res);
            }
        );
    });
    target.appendChild(el);
};

/**
 * 润教育APP的js sdk
 */

var APP = function (ref) {
    var loginPing = ref.loginPing;
    var loginWithCode = ref.loginWithCode;
    var logout = ref.logout;

    return ({
    back: function back() {
        window.history.back();
    },
    loginStatus: function loginStatus$1() {
        return loginStatus$2(loginPing, loginWithCode)
    },
    login: function login$1(ref) {
        if ( ref === void 0 ) ref = {};
        var returnUrl = ref.returnUrl;
        var replace = ref.replace;

        return login$3({ loginWithCode: loginWithCode, returnUrl: returnUrl, replace: replace })
    },
    logout: function logout$1() {
        return logout().then(function () {
            logoutSDK();
            return 'runedu'
        })
    },
    pay: pay$2,
    shareButton: shareButton$1,
    share: share,
    geolocation: geolocation$2,
    open: open,
    uploadImg: function uploadImg$1(target, options, params) {
        upload(target, options, params, uploadImg);
    },
    uploadVideo: function uploadVideo$1(target, options, params) {
        upload(target, options, params, uploadVideo);
    },
    downloadImg: downloadImg$1,
    previewImages: function previewImages(urls, index) {
        if ( index === void 0 ) index = 1;

        open(urls[index - 1]);
    }
});
};

var target = 'wechat-miniprogram';

var WeChatMiniprogram = function (ref) {
    var loginPing = ref.loginPing;
    var loginUrlMiniProgram = ref.loginUrlMiniProgram;
    var logout = ref.logout;
    var miniProgramWidow = ref.miniProgramWidow;
    var getWechatSdkConfig = ref.getWechatSdkConfig;
    var upload = ref.upload;

    var getSDK = getWechatSDK(getWechatSdkConfig);

    return {
        back: function back() {
            getSDK().then(function (sdk) {
                sdk.miniProgram.navigateBack();
            });
        },
        loginStatus: function loginStatus() {
            return loginPing({ from: target })
        },
        login: function login() {
            return getSDK().then(
                function (sdk) { return new Promise(function (success, fail) {
                        sdk.miniProgram.navigateTo({
                            url: loginUrlMiniProgram,
                            success: success,
                            fail: fail
                        });
                    }); }
            )
        },
        logout: function logout$1() {
            return logout().then(function () { return target; })
        },
        pay: function pay() {
            return Promise.reject(new Error('微信小程序内嵌网页暂不支持支付'))
        },
        shareButton: function shareButton() {
            // 暂不处理
        },
        share: function share() {
            // 暂不处理
        },
        open: function open(url, type) {
            return getSDK().then(
                function (sdk) { return new Promise(function (success, fail) {
                        if (type === 'switch') {
                            sdk.miniProgram.switchTab({
                                url: url,
                                success: success,
                                fail: fail
                            });
                        } else if (type === 'page') {
                            sdk.miniProgram.navigateTo({
                                url: url,
                                success: success,
                                fail: fail
                            });
                        } else {
                            sdk.miniProgram.navigateTo({
                                url: (miniProgramWidow + "?url=" + (encodeURIComponent(url))),
                                success: success,
                                fail: fail
                            });
                        }
                    }); }
            )
        },
        geolocation: function geolocation() {
            return getSDK().then(
                function (sdk) { return new Promise(function (success) {
                        sdk.getLocation({
                            type: 'wgs84',
                            success: success
                        });
                    }); }
            )
        },
        previewImages: function previewImages(urls, index) {
            if ( index === void 0 ) index = 1;

            getSDK().then(function (sdk) {
                // 待测试
                sdk.previewImage({
                    urls: urls,
                    current: urls[index - 1]
                });
            });
        },
        downloadImg: downloadImg,
        uploadImg: function uploadImg(target, options, params) {
            uploadFile(target, options, params, upload);
        },
        uploadVideo: function uploadVideo(target, options, params) {
            uploadFile(target, options, params, upload);
        }
    }
};

var formatPayParams = function (ref) {
    var params = ref.params; if ( params === void 0 ) params = {};
    var type = ref.type;
    var returnUrl = ref.returnUrl; if ( returnUrl === void 0 ) returnUrl = window.location.href;

    var thirdPayType;
    var r;

    if (isAPP) {
        thirdPayType = type === 1 ? 4 : 2;
    } else if (type === 2) {
        thirdPayType = 1;
    } else {
        thirdPayType = 3;
        r = returnUrl;
    }

    return Object.assign(params, {
        thirdPayType: thirdPayType,
        returnUrl: r
    })
};

var index = function (options) {
    if ( options === void 0 ) options = {};

    var SDK;

    if (isAPP) {
        SDK = APP;
    } else if (isWeChatMiniprogram) {
        SDK = WeChatMiniprogram;
    } else if (isWeChat) {
        SDK = Wechat;
    } else {
        SDK = Web;
    }

    var sdk = SDK(options);
    var talkingdataAPPID = options.talkingdataAPPID;
    var baidutongjiAPPID = options.baidutongjiAPPID;

    sdk.formatPayParams = formatPayParams;

    if (talkingdataAPPID) {
        sdk.report = TD(talkingdataAPPID);
    }

    if (baidutongjiAPPID) {
        BDTJ(baidutongjiAPPID);
    }

    return sdk
};

return index;

})));
